Skip to contents

Reads an HTML file and extracts preeclampsia risk scores and biomarker MoM values

Usage

extract_risk_scores_from_file(html_file, report_as_text = FALSE)

Arguments

html_file

String, path to HTML file

report_as_text

Boolean, whether to return risks as text fractions (default: FALSE)

Value

List containing risk scores and MoM values (see extract_risk_scores)