Skip to contents

Calculates the prior risk of preeclampsia based on maternal characteristics

Usage

get_prior(form_data, g = 37, pnorm = FALSE)

Arguments

form_data

A list containing maternal characteristics and medical history

g

Numeric, gestational age for risk calculation (default: 37)

pnorm

Boolean, whether to return probability from normal distribution (default: FALSE)

Value

Numeric value representing the prior risk