Skip to contents

This function provides access to a validation dataset included in the package. The dataset is stored as a CSV file in the extdata directory of the package.

Usage

get_validation_data()

Value

A data.table object containing the contents of the validation dataset.