Retrieve Demo Dataset
get_demo_data.RdThis function provides access to a demo dataset included in the package.
The dataset is stored as a CSV file in the extdata directory of the package.
Examples
if (FALSE) { # \dontrun{
# Load the demo dataset
demo_data <- get_demo_data()
head(demo_data)
} # }