Retrieve Validation Dataset
get_validation_data.RdThis function provides access to a validation dataset included in the package.
The dataset is stored as a CSV file in the extdata directory of the package.
get_validation_data.RdThis function provides access to a validation dataset included in the package.
The dataset is stored as a CSV file in the extdata directory of the package.